--------------------------------------------------------------------------------
-- Module Declaration
--

local mod = BigWigs:NewBoss("Yor'sahj Priority", 824)
if not mod then return end
mod:RegisterEnableMob(55312)
mod.toggleOptions = {"blobs"}

local YL = BigWigs.bossCore:GetModule("Yor'sahj the Unsleeping"):GetLocale()

--------------------------------------------------------------------------------
-- Localization
--

local L = mod:NewLocale("enUS", true)
if L then
	L.modname = "Yor'sahj Priority"

	L.blobs = "Blobs"
	L.blobs_desc = "Tells you which blob to kill."
	L.blobs_icon = "achievement_doublerainbow"
	L.blobs_message = "KILL >>%s<<"
end
L = mod:GetLocale()
mod.displayName = L["modname"]

--------------------------------------------------------------------------------
-- Initialization
--

function mod:OnBossEnable()
	if not self.db.profile.blobsNorm then
		self.db.profile.blobsNorm = {
			[105420] = "green",
			[105435] = "green",
			[105436] = "green",
			[105437] = "purple",
			[105439] = "blue",
			[105440] = "purple",
		}
	end
	--[[if not self.db.profile.blobsHC then
		self.db.profile.blobsHC = {
			[105420] = green,
			[105435] = green,
			[105436] = green,
			[105437] = purple,
			[105439] = blue,
			[105440] = purple,
		}
	end]]
	if not self.db.profile.blobsLFR then
		self.db.profile.blobsLFR = {
			[105420] = "purple",
			[105435] = "green",
			[105436] = "green",
			[105437] = "purple",
			[105439] = "yellow",
			[105440] = "purple",
		}
	end

	self:RegisterEvent("UNIT_SPELLCAST_SUCCEEDED", "Blobs")
	self:Death("Disable", 55312)

	if YorsahjPriority then return end
	local yp = CreateFrame("Frame", "YorsahjPriority", InterfaceOptionsFramePanelContainer)
	yp.name = "Big Wigs "..L["modname"]
	InterfaceOptions_AddCategory(yp)
	local ypTitle = yp:CreateFontString(nil, "ARTWORK", "GameFontNormalHuge")
	ypTitle:SetPoint("CENTER", yp, "TOP", 0, -30)
	ypTitle:SetText(yp.name.." r5") --wowace magic, replaced with tag version

	local blobText = yp:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	blobText:SetPoint("TOPLEFT", 20, -100)
	blobText:SetText("NormalNormalNormalHeroic")

	local blobSliderText = yp:CreateFontString("ypSliderText", "ARTWORK", "GameFontNormal")
	blobSliderText:SetPoint("TOPLEFT", 300, -100)
	local diff
	if mod:LFR() then
		diff = "LFR"
	elseif mod:Difficulty() > 2 then
		diff = "Heroic"
	else
		diff = "Normal"
	end
	blobSliderText:SetText("Current Difficulty: "..diff)

	local function updateBlob(frame, value)
		if mod:LFR() then
			mod.db.profile.blobsLFR[frame.spell] = frame.values[value]
		elseif mod:Difficulty() > 2 then
			mod.db.profile.blobsHC[frame.spell] = frame.values[value]
		else
			mod.db.profile.blobsNorm[frame.spell] = frame.values[value]
		end
		_G[frame:GetName().."Text"]:SetText(YL[frame.values[value]])
	end

	local function onShowBlob(frame)
		if not IsInInstance() then
			frame:Hide()
			ypSliderText:SetText("Current Difficulty: ??")
		end
		frame:SetMinMaxValues(1, mod:Difficulty() > 2 and 4 or 3)
		local options
		if mod:LFR() then
			options = mod.db.profile.blobsLFR
		elseif mod:Difficulty() > 2 then
			options = mod.db.profile.blobsHC
		else
			options = mod.db.profile.blobsNorm
		end
		for i=1, #frame.values do
			if frame.values[i] == options[frame.spell] then
				frame:SetValue(i)
				_G[frame:GetName().."Text"]:SetText(YL[frame.values[i]])
			end
		end
	end

	local blobSlider1 = CreateFrame("Slider", "ypSlider1", yp, "OptionsSliderTemplate")
	blobSlider1:SetMinMaxValues(1, self:Difficulty() > 2 and 4 or 3)
	blobSlider1:SetValueStep(1)
	blobSlider1.values = {"purple", "green", "blue", "black"}
	blobSlider1.spell = 105420
	blobSlider1:SetScript("OnValueChanged", updateBlob)
	blobSlider1:SetScript("OnShow", onShowBlob)
	ypSlider1High:SetText("")
	ypSlider1Low:SetText("")
	blobSlider1:SetPoint("TOPLEFT", 300, -150)
	onShowBlob(blobSlider1)

	local blobSlider2 = CreateFrame("Slider", "ypSlider2", yp, "OptionsSliderTemplate")
	blobSlider2:SetMinMaxValues(1, self:Difficulty() > 2 and 4 or 3)
	blobSlider2:SetValueStep(1)
	blobSlider2.values = {"green", "red", "black", "blue"}
	blobSlider2.spell = 105435
	blobSlider2:SetScript("OnValueChanged", updateBlob)
	blobSlider2:SetScript("OnShow", onShowBlob)
	ypSlider2High:SetText("")
	ypSlider2Low:SetText("")
	blobSlider2:SetPoint("TOPLEFT", 300, -200)
	onShowBlob(blobSlider2)

	local blobSlider3 = CreateFrame("Slider", "ypSlider3", yp, "OptionsSliderTemplate")
	blobSlider3:SetMinMaxValues(1, self:Difficulty() > 2 and 4 or 3)
	blobSlider3:SetValueStep(1)
	blobSlider3.values = {"green", "yellow", "red", "black"}
	blobSlider3.spell = 105436
	blobSlider3:SetScript("OnValueChanged", updateBlob)
	blobSlider3:SetScript("OnShow", onShowBlob)
	ypSlider3High:SetText("")
	ypSlider3Low:SetText("")
	blobSlider3:SetPoint("TOPLEFT", 300, -250)
	onShowBlob(blobSlider3)

	local blobSlider4 = CreateFrame("Slider", "ypSlider4", yp, "OptionsSliderTemplate")
	blobSlider4:SetMinMaxValues(1, self:Difficulty() > 2 and 4 or 3)
	blobSlider4:SetValueStep(1)
	blobSlider4.values = {"blue", "purple", "yellow", "green"}
	blobSlider4.spell = 105437
	blobSlider4:SetScript("OnValueChanged", updateBlob)
	blobSlider4:SetScript("OnShow", onShowBlob)
	ypSlider4High:SetText("")
	ypSlider4Low:SetText("")
	blobSlider4:SetPoint("TOPLEFT", 300, -300)
	onShowBlob(blobSlider4)

	local blobSlider5 = CreateFrame("Slider", "ypSlider5", yp, "OptionsSliderTemplate")
	blobSlider5:SetMinMaxValues(1, self:Difficulty() > 2 and 4 or 3)
	blobSlider5:SetValueStep(1)
	blobSlider5.values = {"blue", "black", "yellow", "purple"}
	blobSlider5.spell = 105439
	blobSlider5:SetScript("OnValueChanged", updateBlob)
	blobSlider5:SetScript("OnShow", onShowBlob)
	ypSlider5High:SetText("")
	ypSlider5Low:SetText("")
	blobSlider5:SetPoint("TOPLEFT", 300, -350)
	onShowBlob(blobSlider5)

	local blobSlider6 = CreateFrame("Slider", "ypSlider6", yp, "OptionsSliderTemplate")
	blobSlider6:SetMinMaxValues(1, self:Difficulty() > 2 and 4 or 3)
	blobSlider6:SetValueStep(1)
	blobSlider6.values = {"purple", "red", "black", "yellow"}
	blobSlider6.spell = 105440
	blobSlider6:SetScript("OnValueChanged", updateBlob)
	blobSlider6:SetScript("OnShow", onShowBlob)
	ypSlider6High:SetText("")
	ypSlider6Low:SetText("")
	blobSlider6:SetPoint("TOPLEFT", 300, -400)
	onShowBlob(blobSlider6)

	local blobText1 = yp:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	blobText1:SetPoint("TOPLEFT", 20, -150)
	blobText1:SetText(YL.purple..YL.green..YL.blue..YL.black)

	local blobText2 = yp:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	blobText2:SetPoint("TOPLEFT", 20, -200)
	blobText2:SetText(YL.green..YL.red..YL.black..YL.blue)

	local blobText3 = yp:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	blobText3:SetPoint("TOPLEFT", 20, -250)
	blobText3:SetText(YL.green..YL.yellow..YL.red..YL.black)

	local blobText4 = yp:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	blobText4:SetPoint("TOPLEFT", 20, -300)
	blobText4:SetText(YL.blue..YL.purple..YL.yellow..YL.green)

	local blobText5 = yp:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	blobText5:SetPoint("TOPLEFT", 20, -350)
	blobText5:SetText(YL.blue..YL.black..YL.yellow..YL.purple)

	local blobText6 = yp:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	blobText6:SetPoint("TOPLEFT", 20, -400)
	blobText6:SetText(YL.purple..YL.red..YL.black..YL.yellow)
end

--------------------------------------------------------------------------------
-- Event Handlers
--


function mod:Blobs(_, unit, spellName, _, _, spellId)
	if unit == "boss1" and self.db.profile.blobsNorm[spellId] then
		if self:LFR() then
			for i=1, 2 do
				self:Message("blobs", L["blobs_message"]:format(YL[self.db.profile.blobsLFR[spellId]]), "Important", L["blobs_icon"])
			end
			return
		end
		if self:Difficulty() > 2 then
			--for i=1, 2 do
				--self:Message("blobs", L["blobs_message"]:format(YL[self.db.profile.blobsHC[spellId]]), "Important", L["blobs_icon"])
			--end
		else
			for i=1, 2 do
				self:Message("blobs", L["blobs_message"]:format(YL[self.db.profile.blobsNorm[spellId]]), "Important", L["blobs_icon"])
			end
		end
	end
end

